source('setup_RITAN.R') # loads suggested resources - those with data redistribution prohibition
require(venn)
require(xlsx)
options(width=120)

## ----------------------------------------------------- -
## BRCA genesets
sn <- c('LumB_LumA','Her2_LumA','Basel_LumA')
nq <- function(x){ setdiff(x,c('?','',' ','.')) }
de <- lapply( sn, function(x){ read.xlsx( 'DEAnalyses_pairwise-TCBA_BRCA_EdgeR.xlsx', sheetName=x ) })
de <- lapply(de, function(x){
  x$symbol <- sapply(x$GeneSymbol, function(y){ sub('[|].*','',y,perl=TRUE) })
  return(x)
})
names(de) <- sn

## ----------------------------------------------------- -
## Interesting Venn Diagram
pdf( 'BRCA_Ann_Venn.pdf', height = 3, width = 3 )
venn::venn( list( 'LumA\nversus\nBasel'    = de$Basel_LumA$symbol %>% nq,
                  'LumA\nversus\nHer2'     = de$Her2_LumA$symbol %>% nq,
                  'Orphanet' = geneset_list$orphanet %>% unlist %>% unique,
                  'CORUM' = geneset_list$CORUM %>% unlist %>% unique,
                  'NetPath' = geneset_list$NetPath_Gene_regulation %>% unlist %>% unique
                  ), zcolor = 'style' )
dev.off()

## ----------------------------------------------------- -
## Name the protein complexes with DE genes
g_search <- intersect( geneset_list$CORUM %>% unlist %>% unique,
                       c( de$Basel_LumA$symbol, de$Her2_LumA$symbol ) %>% nq %>% unique )
corum_hits <- sapply( geneset_list$CORUM, function(x){ sum(x %in% g_search) })
table( corum_hits ) %>% sort

names( corum_hits ) <- names( geneset_list$CORUM )
i <- corum_hits >= 3
corum_hits[i] %>% sort

## ----------------------------------------------------- -
## Name of rare/orphaned diseases by DE genes
g_search <- intersect( geneset_list$orphanet %>% unlist %>% unique,
                       c( de$Basel_LumA$symbol, de$Her2_LumA$symbol ) %>% nq %>% unique )
orphanet_hits <- sapply( geneset_list$orphanet, function(x){ sum(x %in% g_search) })
table(orphanet_hits)  %>% sort

names( orphanet_hits ) <- names( geneset_list$orphanet )
i <- orphanet_hits >= 3
orphanet_hits[i] %>% sort

## ----------------------------------------------------- -
## Group-wise enrichment
g <- list(
  'All' = c( de$Basel_LumA$symbol, de$Her2_LumA$symbol ) %>% nq %>% unique,
  'Basel versus LumA'          =            de$Basel_LumA$symbol %>% nq,
  'Orphan & Basel versus LumA' = intersect( de$Basel_LumA$symbol, geneset_list$orphanet ) %>% nq %>% unlist %>% unique,
  'Her2 versus LumA'           =            de$Her2_LumA$symbol %>% nq,
  'Orphan & Her2 versus LumA'  = intersect( de$Her2_LumA$symbol , geneset_list$orphanet ) %>% nq %>% unlist %>% unique )
)

e <- list()
e$R <- term_enrichment_by_subset(g, resources = 'NetPath_Gene_regulation')
e$P <- term_enrichment_by_subset(g, resources = 'ReactomePathways' )
e$G <- term_enrichment_by_subset(g, resources = "GO" )
e$G <- e$G[ apply(e$G[, 4:7], 1, max ) >= 3,  ]
sapply( e, dim )

pdf('enrichment_heatmaps.pdf', height=6, width=8)
plot(e$R        , label_angle_x=-60, wrap_y_labels=NA,label_size_x = 9 )
plot(e$P, cap=5 , label_angle_x=-60, wrap_y_labels=NA,label_size_x = 9 )
plot(e$P        , label_angle_x=-60, wrap_y_labels=NA,label_size_x = 9 )
plot(e$G, cap=10, label_angle_x=-60, wrap_y_labels=NA,label_size_x = 9 )
plot(e$G        , label_angle_x=-60, wrap_y_labels=NA,label_size_x = 9 )
dev.off()

## ----------------------------------------------------- -
## Compare GO and Reactome resources
o <- geneset_overlap( geneset_list$GO, geneset_list$ReactomePathways )

pdf( 'overlap_GO_Reactome_density.pdf', height=3, width=4 )
plot( density(c(o)), log='y',
      main='', xlab='Fraction Shared Genes', ylab='Prob()')
dev.off()

i <- which( o >= 1, arr.ind = TRUE )
mat1 <- o[ unique(i[,1]), unique(i[,2]) ]

i <- which( (o > 0.95) & (o < 1), arr.ind = TRUE )
mat2 <- o[ unique(i[,1]), unique(i[,2]) ]

pdf( 'overlap_GO_Reactome_heatmaps.pdf', height=5, width=5 )
heatmap( mat1, col = rev(gray(seq(0,1,length.out = 15))), labRow = FALSE, labCol = FALSE, margins = c(2,2) )
heatmap( mat2, col = rev(gray(seq(0,1,length.out = 15))), cexRow=.1, cexCol=0.1, margins = c(7,7) )
dev.off()
